<?php

namespace QUI\TrustedShops;

use QUI;
use QUI\Exception;
use QUI\Smarty\Collector;

class Events
{
    public static function onQuiqqerTemplateBodyEnd(
        Collector $Collection,
        QUI\Template $Template
    ): void {
        $urlOptDir = URL_OPT_DIR;

        $Project = QUI::getProjectManager()->get();
        $status = $Project->getConfig('trustedshops.widget.status');
        $tsid = $Project->getConfig('trustedshops.general.trustedShopId');
        $gStatus = $Project->getConfig('trustedshops.guarantee.status');

        if (empty($tsid)) {
            return;
        }


        // load only the trustedshops js
        if (empty($status) && !empty($gStatus)) {
            $Collection->append(
                "<script>window.TRUSTED_SHOPS_ID = '$tsid';</script>" .
                "<script type=\"text/javascript\" src=\"{$urlOptDir}quiqqer/trustedshops/bin/trustedshops.js\"></script>"
            );
            return;
        }

        if (empty($status)) {
            return;
        }

        // @todo bei order seitentypen nicht anzeigen

        $yOffset = (int)$Project->getConfig('trustedshops.widget.widgetYOffset');
        $variant = $Project->getConfig('trustedshops.widget.widgetVariant');
        $customId = $Project->getConfig('trustedshops.widget.customElementId');
        $direction = $Project->getConfig('trustedshops.widget.trustcardDirection');
        $disableResponsive = $Project->getConfig('trustedshops.widget.disableResponsive');
        $disableTrustbadge = $Project->getConfig('trustedshops.widget.disableTrustbadge');

        if (empty($disableResponsive)) {
            $disableResponsive = 'false';
        } else {
            $disableResponsive = 'true';
        }

        if (empty($disableTrustbadge)) {
            $disableTrustbadge = 'false';
        } else {
            $disableTrustbadge = 'true';
        }

        // position
        $cssClass = 'bottomRight';

        switch ($direction) {
            case 'topRight':
            case 'topLeft':
            case 'bottomRight':
            case 'bottomLeft':
                $cssClass = $direction;
                break;
        }

        // variant
        switch ($variant) {
            case 'default':
                $variant = 'custom';
                break;

            case 'reviews':
                $variant = 'custom_reviews';
                break;
        }

        $Collection->append(
            "
            <link href=\"{$urlOptDir}quiqqer/trustedshops/bin/trustedshops.css\" rel=\"stylesheet\">
            <div id='quiqqer-trusted-shop' class='quiqqer-trusted-shop--$variant quiqqer-trusted-shop--$cssClass'>
                <div id='trustbadgeCustomContainer'></div>
            </div>
            <script type='text/javascript'>
              (function () { 
                 'use strict';
                window.TRUSTED_SHOPS_ID = '$tsid'; 
                
                window._tsConfig = {
                  'yOffset': '$yOffset', /* offset from page bottom */
                  'variant': '$variant', /* default, reviews, custom, custom_reviews */
                  'customElementId': '$customId', /* required for variants custom and custom_reviews */
                  'trustcardDirection': '', /* for custom variants: topRight, topLeft, bottomRight, bottomLeft */
                  'customBadgeWidth': '', /* for custom variants: 40 - 90 (in pixels) */
                  'customBadgeHeight': '', /* for custom variants: 40 - 90 (in pixels) */
                  'disableResponsive': '$disableResponsive', /* deactivate responsive behaviour */
                  'disableTrustbadge': '$disableTrustbadge' /* deactivate trustbadge */
                };
              })();
            </script>
            <script type=\"text/javascript\" src=\"{$urlOptDir}quiqqer/trustedshops/bin/trustedshops.js\"></script>"
        );
    }

    /**
     * @throws Exception
     */
    public static function onOrderProcessFinish(
        Collector $Collection,
        QUI\Interfaces\Users\User $User,
        QUI\ERP\Order\AbstractOrder $Order
    ): void {
        $Project = QUI::getProjectManager()->get();
        $status = $Project->getConfig('trustedshops.guarantee.status');

        TrustedShops::sendOrder($Order, $Project);

        if (!empty($status)) {
            $orderId = $Order->getIdPrefix();
            $Customer = $Order->getCustomer();
            $Currency = $Order->getCurrency();
            $Payment = $Order->getPayment();

            $email = $Customer->getAttribute('email');
            $calc = $Order->getArticles()->getCalculations();
            $currency = $Currency->getCode();
            $payment = $Payment->getTitle();

            $Collection->append(
                "
            <div id='trustedShopsCheckout' style='display: none;'>
                <span id='tsCheckoutOrderNr'>$orderId</span>
                <span id='tsCheckoutBuyerEmail'>$email</span>
                <span id='tsCheckoutOrderAmount'>{$calc['sum']}</span>
                <span id='tsCheckoutOrderCurrency'>$currency</span>
                <span id='tsCheckoutOrderPaymentType'>$payment</span>
                <span id='tsCheckoutOrderEstDeliveryDate'></span>
            </div>
            
            <script>
            if (typeof window.trustbadge !== 'undefined') {
                window.trustbadge.reInitialize();   
            }
            </script>
            "
            );
        }
    }
}
